/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StreamPrivatelinkEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
    * Domain name of Privatelink connected cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#dns_domain StreamPrivatelinkEndpoint#dns_domain}
    */
    readonly dnsDomain?: string;
    /**
    * Sub-Domain name of Confluent cluster. These are typically your availability zones.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#dns_sub_domain StreamPrivatelinkEndpoint#dns_sub_domain}
    */
    readonly dnsSubDomain?: string[];
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group or project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#project_id StreamPrivatelinkEndpoint#project_id}
    */
    readonly projectId: string;
    /**
    * Provider where the Kafka cluster is deployed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#provider_name StreamPrivatelinkEndpoint#provider_name}
    */
    readonly providerName: string;
    /**
    * Domain name of Confluent cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#region StreamPrivatelinkEndpoint#region}
    */
    readonly region?: string;
    /**
    * Service Endpoint ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#service_endpoint_id StreamPrivatelinkEndpoint#service_endpoint_id}
    */
    readonly serviceEndpointId?: string;
    /**
    * Vendor who manages the Kafka cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#vendor StreamPrivatelinkEndpoint#vendor}
    */
    readonly vendor: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint mongodbatlas_stream_privatelink_endpoint}
*/
export declare class StreamPrivatelinkEndpoint extends cdktf.TerraformResource {
    static readonly tfResourceType = "mongodbatlas_stream_privatelink_endpoint";
    /**
    * Generates CDKTF code for importing a StreamPrivatelinkEndpoint resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StreamPrivatelinkEndpoint to import
    * @param importFromId The id of the existing StreamPrivatelinkEndpoint that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StreamPrivatelinkEndpoint to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.29.0/docs/resources/stream_privatelink_endpoint mongodbatlas_stream_privatelink_endpoint} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StreamPrivatelinkEndpointConfig
    */
    constructor(scope: Construct, id: string, config: StreamPrivatelinkEndpointConfig);
    private _dnsDomain?;
    get dnsDomain(): string;
    set dnsDomain(value: string);
    resetDnsDomain(): void;
    get dnsDomainInput(): string | undefined;
    private _dnsSubDomain?;
    get dnsSubDomain(): string[];
    set dnsSubDomain(value: string[]);
    resetDnsSubDomain(): void;
    get dnsSubDomainInput(): string[] | undefined;
    get id(): string;
    get interfaceEndpointId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _providerName?;
    get providerName(): string;
    set providerName(value: string);
    get providerNameInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _serviceEndpointId?;
    get serviceEndpointId(): string;
    set serviceEndpointId(value: string);
    resetServiceEndpointId(): void;
    get serviceEndpointIdInput(): string | undefined;
    get state(): string;
    private _vendor?;
    get vendor(): string;
    set vendor(value: string);
    get vendorInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
